@@ -5,7 +5,9 @@ Primary means of using KIPET is through the KipetModel class
 """
 # Standard library imports
 import collections
+import os
 import pathlib
+import sys
 
 # Third party imports
 import pandas as pd
@@ -135,7 +137,7 @@ class KipetModel():
         
         if model is None:
         
-            self.models[name] = ReactionModel(name=name)
+            self.models[name] = ReactionModel(name=name, unit_base=self.ub)
 #            self.models[name].settings.general.data_directory = self.settings.general.data_directory
             
             assign_list = ['components', 'parameters', 'constants', 'algebraics',
@@ -149,7 +151,7 @@ class KipetModel():
             if isinstance(model, ReactionModel):
                 kwargs = {}
                 kwargs['name'] = name
-                self.models[name] = ReactionModel(name=name)
+                self.models[name] = ReactionModel(name=name, unit_base=self.ub)
                 
                 assign_list = ['components', 'parameters', 'constants', 'algebraics',
                              'states', 'ub', 'settings', 'c', 'odes_dict']
@@ -172,8 +174,9 @@ class KipetModel():
     def add_reaction(self, kipet_model_instance):
     
         if isinstance(kipet_model_instance, ReactionModel):
+            kipet_model_instance.unit_base = self.ub
             self.models[kipet_model_instance.name] = kipet_model_instance
-            self.models[kipet_model_instance.name].settings.general.data_directory = self.settings.general.data_directory
+            #self.models[kipet_model_instance.name].settings.general.data_directory = self.settings.general.data_directory
         else:
             raise ValueError('KipetModel can only add ReactionModel instances.')
 
@@ -418,12 +421,14 @@ class KipetModel():
         
         """
         _filename = filename
-        if directory is None:
-            _filename = _set_directory(self, filename)
-        else:
-            _filename = pathlib.Path(directory).joinpath(filename)
-        if not _filename.parent.is_dir():
-            _filename.parent.mkdir(exist_ok=True)
+        # if directory is None:
+        #     _filename = _set_directory(self, filename)
+        # else:
+        #     _filename = pathlib.Path(directory).joinpath(filename)
+        # if not _filename.parent.is_dir():
+        #     _filename.parent.mkdir(exist_ok=True)
+        calling_file_name = os.path.dirname(os.path.realpath(sys.argv[0]))
+        _filename = pathlib.Path(calling_file_name).joinpath(_filename)
         data_tools.write_file(_filename, data)
         
         return None
@@ -443,11 +448,13 @@ class KipetModel():
         
         """
         _filename = filename
-        if directory is None:
-            _filename = _set_directory(self, filename)
-        else:
-            _filename = pathlib.Path(directory).joinpath(filename)
+        # if directory is None:
+        #     _filename = _set_directory(self, filename)
+        # else:
+        #     _filename = pathlib.Path(directory).joinpath(filename)
         
+        calling_file_name = os.path.dirname(os.path.realpath(sys.argv[0]))
+        _filename = pathlib.Path(calling_file_name).joinpath(_filename)
         read_data = data_tools.read_file(_filename)
         
         return read_data
